@@ -362,3 +362,17 @@ void PuntateMain::on_stream23_clicked()
     process.start("sh /opt/serviziopubblico/script/p23.sh");
     process.waitForFinished();
 }
+
+void PuntateMain::on_down24_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/d24.sh");
+    process.waitForFinished();
+}
+
+void PuntateMain::on_stream24_clicked()
+{
+    QProcess process;
+    process.start("sh /opt/serviziopubblico/script/p24.sh");
+    process.waitForFinished();
+}
