@@ -112,6 +112,10 @@ private slots:
 
     void on_stream23_clicked();
 
+    void on_down24_clicked();
+
+    void on_stream24_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
